@@ -38,13 +38,20 @@
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
+#if defined(_WIN32) && !defined(__CYGWIN__)
+#define WIN32_LEAN_AND_MEAN
+#include <windows.h>
+#undef SLIST_ENTRY
+#endif
 #include "getopt.h"
 
 #include "global.h"
 #include "parser.h"
 #include "regex.h"
 #include "const.h"
+#include "output.h"
 #include "literal.h"
+#include "convert.h"
 
 /**
  * @file global.c
@@ -64,9 +71,6 @@ void grep(const char *, char *const *, const char *);
 void pathlist(const char *, const char *);
 void parsefile(char *const *, const char *, const char *, const char *, int);
 int search(const char *, const char *, const char *, const char *, int);
-void start_output();
-void end_output();
-int output_with_formatting(CONVERT *, GTP *, int);
 void tagsearch(const char *, const char *, const char *, const char *, int);
 void encode(char *, int, const char *);
 
@@ -106,6 +110,7 @@ int format;
 int type;				/**< path conversion type */
 int match_part;				/**< match part only	*/
 int abslib;				/**< absolute path only in library project */
+char use_color;				/**< coloring */
 const char *cwd;			/**< current directory	*/
 const char *root;			/**< root of source tree	*/
 const char *dbpath;			/**< dbpath directory	*/
@@ -117,6 +122,14 @@ char *encode_chars;
 char *single_update;
 char *path_style;
 
+/**
+ * @name Path filter
+ */
+/** @{ */
+int do_path;
+int convert_type = PATH_RELATIVE;
+/** @} */
+
 static void
 usage(void)
 {
@@ -138,6 +151,8 @@ help(void)
 #define MATCH_PART	131
 #define SINGLE_UPDATE	132
 #define PATH_STYLE	133
+#define PATH_CONVERT	134
+#define USE_COLOR	135
 #define SORT_FILTER     1
 #define PATH_FILTER     2
 #define BOTH_FILTER     (SORT_FILTER|PATH_FILTER)
@@ -175,12 +190,14 @@ static struct option const long_options[] = {
 	{"cxref", no_argument, NULL, 'x'},
 
 	/* long name only */
+	{"color", optional_argument, NULL, USE_COLOR},
 	{"encode-path", required_argument, NULL, ENCODE_PATH},
 	{"from-here", required_argument, NULL, FROM_HERE},
 	{"debug", no_argument, &debug, 1},
 	{"literal", no_argument, &literal, 1},
 	{"match-part", required_argument, NULL, MATCH_PART},
 	{"path-style", required_argument, NULL, PATH_STYLE},
+	{"path-convert", required_argument, NULL, PATH_CONVERT},
 	{"print0", no_argument, &print0, 1},
 	{"version", no_argument, &show_version, 1},
 	{"help", no_argument, &show_help, 1},
@@ -341,7 +358,7 @@ main(int argc, char **argv)
 	int option_index = 0;
 
 	logging_arguments(argc, argv);
-	while ((optchar = getopt_long(argc, argv, "acde:ifgGIlL:noOpPqrsS:tTuvVx", long_options, &option_index)) != EOF) {
+	while ((optchar = getopt_long(argc, argv, "acCde:ifgGIlL:noOpPqrsS:tTuvVx", long_options, &option_index)) != EOF) {
 		switch (optchar) {
 		case 0:
 			break;
@@ -443,6 +460,20 @@ main(int argc, char **argv)
 		case 'x':
 			xflag++;
 			break;
+		case USE_COLOR:
+			if (optarg) {
+				if (!strcmp(optarg, "never"))
+					use_color = 0;
+				else if (!strcmp(optarg, "always"))
+					use_color = 1;
+				else if (!strcmp(optarg, "auto"))
+					use_color = 2;
+				else
+					die_with_code(2, "unknown color type.");
+			} else {
+				use_color = 2;
+			}
+			break;
 		case ENCODE_PATH:
 			encode_chars = optarg;
 			break;
@@ -472,6 +503,17 @@ main(int argc, char **argv)
 			else
 				die_with_code(2, "unknown part type for the --match-part option.");
 			break;
+		case PATH_CONVERT:
+			do_path = 1;
+			if (!strcmp("absolute", optarg))
+				convert_type = PATH_ABSOLUTE;
+			else if (!strcmp("relative", optarg))
+				convert_type = PATH_RELATIVE;
+			else if (!strcmp("through", optarg))
+				convert_type = PATH_THROUGH;
+			else
+				die("Unknown path type.");
+			break;
 		case PATH_STYLE:
 			path_style = optarg;
 			break;
@@ -535,11 +577,57 @@ main(int argc, char **argv)
 		Tflag++;
 	if (qflag)
 		vflag = 0;
+	if (use_color) {
+#if defined(_WIN32) && !defined(__CYGWIN__)
+		if (!(getenv("ANSICON") || LoadLibrary("ANSI32.dll")) && use_color == 2)
+			use_color = 0;
+#endif
+		if (use_color == 2 && !isatty(1))
+			use_color = 0;
+		if (Vflag)
+			use_color = 0;
+	}
 	if (show_help)
 		help();
 
 	argc -= optind;
 	argv += optind;
+	/*
+	 * Path filter
+	 */
+	if (do_path) {
+		/*
+		 * This code is needed for globash.rc.
+		 * This code extract path name from tag line and
+		 * replace it with the relative or the absolute path name.
+		 *
+		 * By default, if we are in src/ directory, the output
+		 * should be converted like follws:
+		 *
+		 * main      10 ./src/main.c  main(argc, argv)\n
+		 * main      22 ./libc/func.c   main(argc, argv)\n
+		 *		v
+		 * main      10 main.c  main(argc, argv)\n
+		 * main      22 ../libc/func.c   main(argc, argv)\n
+		 *
+		 * Similarly, the --path-covert=absolute option specified, then
+		 *		v
+		 * main      10 /prj/xxx/src/main.c  main(argc, argv)\n
+		 * main      22 /prj/xxx/libc/func.c   main(argc, argv)\n
+		 */
+		STRBUF *ib = strbuf_open(MAXBUFLEN);
+		CONVERT *cv;
+		char *ctags_x;
+
+		if (argc < 3)
+			die("global --path-covert: 3 arguments needed.");
+		cv = convert_open(convert_type, FORMAT_CTAGS_X, argv[0], argv[1], argv[2], stdout, NOTAGS);
+		while ((ctags_x = strbuf_fgets(ib, stdin, STRBUF_NOCRLF)) != NULL)
+			convert_put(cv, ctags_x);
+		convert_close(cv);
+		strbuf_close(ib);
+		exit(0);
+	}
 	/*
 	 * At first, we pickup pattern from -e option. If it is not found
 	 * then use argument which is not option.
@@ -1026,7 +1114,7 @@ completion_path(const char *dbpath, const char *prefix)
  * +===========================================+
  *
  * Sort filter is implemented in gtagsop module (libutil/gtagsop.c).
- * Path filter is implemented in pathconvert module (libutil/pathconvert.c).
+ * Path filter is implemented in convert module (global/convert.c).
  */
 /**
  * print number of object.
@@ -1099,6 +1187,7 @@ idutils(const char *pattern, const char *dbpath)
 	if (!(ip = popen(strbuf_value(ib), "r")))
 		die("cannot execute '%s'.", strbuf_value(ib));
 	cv = convert_open(type, format, root, cwd, dbpath, stdout, NOTAGS);
+	cv->tag_for_display = encoded_pattern;
 	count = 0;
 	strcpy(path, "./");
 	while ((grep = strbuf_fgets(ib, ip, STRBUF_NOCRLF)) != NULL) {
@@ -1120,7 +1209,7 @@ idutils(const char *pattern, const char *dbpath)
 		count++;
 		switch (format) {
 		case FORMAT_PATH:
-			convert_put_path(cv, path);
+			convert_put_path(cv, NULL, path);
 			break;
 		default:
 			/* extract line number */
@@ -1137,7 +1226,7 @@ idutils(const char *pattern, const char *dbpath)
 			/*
 			 * print out.
 			 */
-			convert_put_using(cv, encoded_pattern, path, linenum, p, NULL);
+			convert_put_using(cv, pattern, path, linenum, p, NULL);
 			break;
 		}
 	}
@@ -1208,6 +1297,7 @@ grep(const char *pattern, char *const *argv, const char *dbpath)
 			die("invalid regular expression.");
 	}
 	cv = convert_open(type, format, root, cwd, dbpath, stdout, NOTAGS);
+	cv->tag_for_display = encoded_pattern;
 	count = 0;
 
 	if (*argv && file_list)
@@ -1254,10 +1344,10 @@ grep(const char *pattern, char *const *argv, const char *dbpath)
 				if ((!Vflag && result == 0) || (Vflag && result != 0)) {
 					count++;
 					if (format == FORMAT_PATH) {
-						convert_put_path(cv, path);
+						convert_put_path(cv, NULL, path);
 						break;
 					} else {
-						convert_put_using(cv, encoded_pattern, path, linenum, buffer,
+						convert_put_using(cv, pattern, path, linenum, buffer,
 							(user_specified) ? NULL : gp->dbop->lastdat);
 					}
 				}
@@ -1319,6 +1409,7 @@ pathlist(const char *pattern, const char *dbpath)
 	if (!localprefix)
 		localprefix = "./";
 	cv = convert_open(type, format, root, cwd, dbpath, stdout, GPATH);
+	cv->tag_for_display = "path";
 	count = 0;
 
 	gp = gfind_open(dbpath, localprefix, target);
@@ -1335,9 +1426,9 @@ pathlist(const char *pattern, const char *dbpath)
 		} else if (Vflag)
 			continue;
 		if (format == FORMAT_PATH)
-			convert_put_path(cv, path);
+			convert_put_path(cv, pattern, path);
 		else
-			convert_put_using(cv, "path", path, 1, " ", gp->dbop->lastdat);
+			convert_put_using(cv, pattern, path, 1, " ", gp->dbop->lastdat);
 		count++;
 	}
 	gfind_close(gp);
@@ -1564,6 +1655,7 @@ search(const char *pattern, const char *root, const char *cwd, const char *dbpat
 	GTP *gtp;
 	int flags = 0;
 
+	start_output();
 	/*
 	 * open tag file.
 	 */
@@ -1589,6 +1681,7 @@ search(const char *pattern, const char *root, const char *cwd, const char *dbpat
 	if (debug)
 		gtags_show_statistics(gtop);
 	gtags_close(gtop);
+	end_output();
 	return count;
 }
 /**
