@@ -32,29 +32,38 @@
 #include "cache.h"
 
 static ASSOC *assoc[GTAGLIM];
-/*
+/**
+ * @file
+ *
  * Cache file is used for duplicate object entry.
  *
+ * @par
  * If function 'func()' is defined more than once then the cache record
- * of GTAGS has (1) the frequency and the name of duplicate object entry file,
- * else it has (2) the tag definition.
+ * of @NAME{GTAGS} has @STRONG{(1)} the frequency and the name of duplicate object entry file,
+ * else it has @STRONG{(2)} the tag definition. <br>
  * It can be distinguished the first character of the cache record.
  * If it is a blank then it is the former else the latter.
  *
- * (1) Duplicate tag file
+ * @par
+ * @STRONG{(1)} Duplicate tag file
+ * @code{.txt}
  *	+-----------------------+
  *	|' '<fid>\0<frequency>\0|
  *	+-----------------------+
- *    Duplicate tag file can be referred to as 'D/<fid>.html'.
+ * @endcode
+ *    Duplicate tag file can be referred to as @FILE{D/\<fid\>.html}.
  *	
- * (2) Tag definition
+ * @par
+ * @STRONG{(2)} Tag definition
+ * @code{.txt}
  *	+----------------------+
  *	|<line number>\0<fid>\0|
  *	+----------------------+
- *    Tag is referred to as 'S/<fid>.html#<line number>'.
+ * @endcode
+ *    Tag is referred to as @FILE{S/\<fid\>.html\#\<line number\>}.
  */
 
-/*
+/**
  * cache_open: open cache file.
  */
 void
@@ -64,12 +73,13 @@ cache_open(void)
 	assoc[GRTAGS] = assoc_open();
 	assoc[GSYMS] = symbol ? assoc_open() : NULL;
 }
-/*
+/**
  * cache_put: put tag line.
  *
- *	i)	db	db type
- *	i)	tag	tag name
- *	i)	line	tag line
+ *	@param[in]	db	db type
+ *	@param[in]	tag	tag name
+ *	@param[in]	line	tag line
+ *	@param[in]	len
  */
 void
 cache_put(int db, const char *tag, const char *line, int len)
@@ -78,12 +88,12 @@ cache_put(int db, const char *tag, const char *line, int len)
 		die("I don't know such tag file.");
 	assoc_put_withlen(assoc[db], tag, line, len);
 }
-/*
+/**
  * cache_get: get tag line.
  *
- *	i)	db	db type
- *	i)	tag	tag name
- *	r)		tag line
+ *	@param[in]	db	db type
+ *	@param[in]	tag	tag name
+ *	@return		tag line
  */
 const char *
 cache_get(int db, const char *tag)
@@ -92,7 +102,7 @@ cache_get(int db, const char *tag)
 		die("I don't know such tag file.");
 	return assoc_get(assoc[db], tag);
 }
-/*
+/**
  * cache_close: close cache file.
  */
 void
