@@ -1,4 +1,4 @@
-/* ANSI-C code produced by gperf version 3.0.4 */
+/* ANSI-C code produced by gperf version 3.0.3 */
 /* Command-line: gperf --language=ANSI-C --struct-type --slot-name=name --hash-fn-name=php_hash --lookup-fn-name=php_lookup  */
 /* Computed positions: -k'1-2,4-6,9' */
 
@@ -165,7 +165,7 @@ php_hash (register const char *str, register unsigned int len)
       603, 603, 603, 603, 603, 603, 603, 603, 603, 603,
       603, 603, 603, 603, 603, 603
     };
-  register int hval = len;
+  register int hval = (int)len;
 
   switch (hval)
     {
@@ -194,12 +194,6 @@ php_hash (register const char *str, register unsigned int len)
   return hval;
 }
 
-#ifdef __GNUC__
-__inline
-#if defined __GNUC_STDC_INLINE__ || defined __GNUC_GNU_INLINE__
-__attribute__ ((__gnu_inline__))
-#endif
-#endif
 struct keyword *
 php_lookup (register const char *str, register unsigned int len)
 {
